Scaffolding for common service patterns
=======================================

In addition to the implementation of GOV.UK Design System in Python, fast-gov-uk includes
many common service patterns like error pages, cookie banner, phase banner, a footer and even
a feedback form.

You have seen the example for creating a simple page. Fast-gov-uk also provides handy tools
to quickly and easily build forms and question pages.

Read the following sections for more details -

.. toctree::
   :maxdepth: 1

   pages
   forms
   wizards
   cookies
   feedback
